无间道 (豆瓣)
Description: 无间道电影简介和剧情介绍,无间道影评、图片、预告片、影讯、论坛、在线购票
Keywords: 无间道,無間道,无间道影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.17豆瓣电影Top250

# 无间道 無間道 (2002)

更新描述或海报

导演: 刘伟强 / 麦兆辉
编剧: 麦兆辉 / 庄文强
主演: 刘德华 / 梁朝伟 / 黄秋生 / 曾志伟 / 陈慧琳 / 郑秀文 / 陈冠希 / 余文乐 / 萧亚轩 / 林家栋 / 吴廷烨 / 林迪安 / 尹志强 / 许金峰 / 何华超 / 利沙华 / 区轩玮 / 李天翔 / 黄燕强 / 姚文基 / 余世腾 / 苏伟南 / 黎志伟 / 梁皓楷 / 张旭燊 / 袁伟豪 / 杜汶泽
类型: 剧情 / 惊悚 / 犯罪
制片国家/地区: 中国香港
语言: 粤语
上映日期: 2003-09-05(中国大陆) / 2002-12-12(中国香港)
片长: 101分钟 / 97分钟(导演剪辑版)
又名: Infernal Affairs / Mou gaan dou
IMDb: tt0338564
豆瓣评分
引用
9.3
1281894人评价
5星
68.7%
4星
27.1%
3星
3.9%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.0
4人评价
好于 99% 犯罪片
好于 99% 剧情片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 无间道的剧情简介 · · · · · ·

1991年，香港黑帮三合会会员刘健明（刘德华）听从老大韩琛（曾志伟）的吩咐，加入警察部队成为黑帮卧底，韩琛许诺刘健明会帮其在七年后晋升为见习督察。1992年，警察训练学校优秀学员陈永仁（梁朝伟）被上级要求深入到三合会做卧底，终极目标是成为韩琛身边的红人。2002年，两人都不负重望，也都身背重压，刘健明渐想成为一个真正的好人，陈永仁则盼着尽快回归警察身份。
重案组从陈永仁手中获悉一批毒品交易情报，锁紧目标人物韩琛，没料情报被刘健明泄出，双方行动均告失败。但此事将双方均有卧底的事实暴露，引发双方高层清除内鬼的决心。命运迥异又相似的刘健明和陈永仁开始在无间道的旅程中接受严峻考验。 ©豆瓣

## 无间道的演职员 · · · · · · ( 全部 52 )

- 刘伟强 导演
- 麦兆辉 导演
- 刘德华 饰 刘建明
- 梁朝伟 饰 陈永仁
- 黄秋生 饰 黄志诚
- 曾志伟 饰 韩琛

## 无间道的视频和图片 · · · · · · ( 预告片3 | 视频评论2 · 添加 | 图片857 · 添加 )

## 无间道的获奖情况 · · · · · · ( 全部 )

- 第40届台北金马影展
- 金马奖 最佳剧情片

- 第22届香港电影金像奖
- 最佳电影

- 第10届华语电影传媒大奖
- 新世纪十年十佳电影

## 喜欢这部电影的人也喜欢 · · · · · ·

  无间道2

  英雄本色

  猫鼠游戏

  教父

  美国往事

  新世界

  无双

  暗战

  纵横四海

  低俗小说

我要写短评

## 无间道的短评 · · · · · · ( 全部 208218 条 )

热门 / 最新 / 好友

### 17686 有用 Tofu 看过 2012-01-22 00:39:38

我还是不能理解为什么美国人可以这么无耻直接拿本子过去拍出烂片还得了奥斯卡但是不给这部片子正名?

### 17581 有用 隆咚锵 看过 2007-03-03 02:07:09

牛就牛在，他让所有演员都达到了巅峰

### 10891 有用 XAr 看过 2008-02-15 00:48:21

当年我深刻的爱上了梁朝伟同学

### 7485 有用 刘小姜 看过 2012-09-14 19:42:32

最后那一下爆头，刘德华和梁朝伟的眼神里都是震惊，他死在电梯里，电梯门来回的开关，我们也从震惊中恢复，觉得残酷，谁说的，好人有好报，那些为民除害的，都死了。会有人惦记着他们吗？把他们视为英雄吗？又有什么用呢，这个社会还不都是恶人当道。

### 6139 有用 影志 看过 2006-02-16 22:18:21

“出来混，迟早要还的。” 别说，这种港片老爸老妈们已经欣赏不了了，就连弟弟一起看都没坚持看完，哎，我说，片子都这么牛逼了，对你们来说却成不了经典，叹息。

> 更多短评 208218条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-03-11 22:45:18

三年又三年，陈永仁说他不想再坏人，而刘德华想做个好人。那么到底最后是放下屠刀立地成佛呢？

我要写影评

## 无间道的影评 · · · · · · ( 全部 1729 条 )

热门 / 最新 / 好友
豆瓣天后董小姐 2011-09-12 13:52:30

## 再回首，已是百年身

一直很喜欢陈永仁（梁朝伟）和他的前女友May（萧亚轩）巧遇的那个桥段， 陈永仁走到May跟前，停下，May挽着两个购物袋，凝望他，轻轻一笑。 陈永仁也腼腆一笑：“这么巧？” “很久没见。” “六、七年了。” “近况如何？” May像煞有介事地说：“我结婚了，你呢？还在道上混... (展开)
7431 274 502回应 收起
Y.X.K 2016-05-31 11:55:19

## 再见，警察

这篇影评可能有剧透

香港的警匪片已经成一种类型片了，在很多年的发展中，警匪片带着匪气和正气，善恶交战却往往善恶难分，这个苗头就是从无间道开始被带起来的，作为当初的救市之作，这部电影被拍了三部，还被日本、美国翻拍，成为一代香港电影经典，他如此吸引人，但是剧情说白了也就是抓卧底、... (展开)
2584 74 124回应 收起
blueroc 2005-09-02 08:46:26

## 【无间道系列】留下的三句话

面对“无间道III终极无间”狂轰滥炸的宣传攻势，我有些按耐不住，I和II都看了，总体感觉不错，只是时间不凑巧，没赶上III的首映。昨晚，终于一睹庐山芳容，自己不是枪手懒得写影评，何况也写得不好，尽管社会上的影评早已经铺天盖地，但也懒得看别人写的。不过，好歹花了不... (展开)
1954 346 187回应 收起
隆咚锵 2008-08-01 13:21:58

## 我本将心向明月，奈何明月照沟渠

当被人问及最喜欢的电影时，我可以毫无迟疑地告诉他，无间道。这是一部极具香港色彩的电影，正如国语班主题曲中所唱得那样，谁了解生存往往比命运还残酷，只是没有人愿意认输。这是一个有关于生存的故事，而似乎“生存”这个主题，在香港这样一个夹缝似的土地上却又如此的尖锐... (展开)
1200 177 138回应 收起
王二仙 2006-08-31 12:58:17

## 《无间道》及以外

《无间道》来自香港，这个比世界上大部分生活水平都好的岛屿，一度是天堂的代号。几个杰出的艺人和一帮高明的商人及用心良苦的故事高手，用命运和职业的格局码出换体思维，在好人坏人之间追问、游离，终而幻灭在规则底线。令人自然想起《变脸》，有点类似的抗争。从导演手法和... (展开)
798 64 49回应 收起
cys.tony 2013-11-03 11:05:35

## 一个演员的巅峰期

早在94年的《重庆森林》，梁朝伟已经凭借一个痴情警察拿到了金像奖影帝，但严格说来，直到97年左右梁生才完全进入自己的巅峰期。这个时期既有《春光乍泄》的苦情小gay，也有《暗花》这样阴暗狠毒的坏警察，《花样年华》更是斩获戛纳影帝，风头之劲一时无两。《无间道》里面的陈... (展开)
599 36 96回应 收起
windfengnie 2006-05-17 23:46:17

## 我帮《无间道》改错

一遍一遍又一遍，我乐此不彼的重温着刘伟强先生的经典作品。我很喜欢《无间道》系列电影 ，其中人物性格的鲜活丰满，演员的精湛演技，剧情的波荡起伏，配乐的缥缈煽情，画面的纯净饱满......都给我留下了很深很深的好印象。我觉得它是我看过的港产电影中最好看的一部之一。在... (展开)
609 175 271回应 收起
今晚八点 2010-05-28 11:11:02

## 《无间道》的悲剧意识

这篇影评可能有剧透

“倘若我们将时间的指针拨回到2002年12月12日，在香港电影快要被人们遗忘时，一部注定要成为经典的电影就这样横空出世了。导演刘伟强在《古惑仔》系列、《中华英雄》与《风云之雄霸天下》之后再战影坛，推出了《无间道I》。该片在与《英雄》和《哈利波特2》等强势大片狭路相逢... (展开)
503 13 15回应 收起
milankun 2005-11-07 13:07:32

## 从《无间道》到地藏王菩萨

我是在HBO上面第一次看到《无间道I》的；距离它的首映，已经两年了。在没有心理准备的情况下，我竟被它稳稳地钉在电视机前面，一个半小时未曾转台。看完之后，我的感觉是，感谢《无间道》，因为，这部片子标志着华人电影工业，以它自己的方式，已经达到完全成熟的地步；而这是... (展开)
281 21 27回应 收起

> 更多影评 1729篇

添加新讨论

## 讨论区 · · · · · ·

最后电梯里两个死人，第二个死的人会不会是刘德华... | 来自㊣o㊣ | 35 回应 | 2022-11-24 04:27:38
与《新世界》相比 | 来自entropy98 | 2 回应 | 2022-11-23 22:22:03
国内不重映吗？ | 来自海 | 3 回应 | 2022-11-22 19:10:05
结尾陈永仁发现刘建明是卧底时为什么跑 | 来自Pugeri | 99 回应 | 2022-11-21 14:11:55
弱弱的问一句，这个电影名是什么意思 | 来自小民乙 |  | 2022-11-21 13:54:15

> 去这部影片的讨论区（全部680条）

## 关于《无间道》的问题 · · · · · · ( 全部81个 )

- 片名《无间道》和无间地狱有关系吗？ 6人回答
- 如果《无间道》里梁朝伟没发现刘德华是卧底，刘德华能做个好人吗？ 31人回答

> 全部81个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看
- 西瓜视频 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 那些和谐的腐剧，腐动画，腐电影们。 (墨 尘)
- 高智商互斗电影 (中间元素)
- 中文电影250强总榜（1905——2012） (东方快车)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- momo
  刚刚 看过
- 慕慕朝朝
  2分钟前 想看
- 葛朗台.杨
  2分钟前 看过

2258109人看过 / 298319人想看

订阅无间道的评论:
feed: rss 2.0